import register from './register'
import './index.css'

import { API, fetchToken, configure } from '@userspace-auth/core'
import { ProfileButtonWebComponent } from './webcomponents/ProfileButton'
import { BadgeWebComponent } from './webcomponents/Badge'
import { UsersTableWebComponent } from './webcomponents/UsersTable'
import { ProfileSettingsWebComponent } from './webcomponents/ProfileSettings'
import { ChangePasswordWebComponent } from './webcomponents/ChangePassword'
import { SettingsWebComponent } from './webcomponents/Settings'
import { PortalWebComponent } from './webcomponents/Portal'
import { AuthorizedWebComponent, NonAuthorizedWebComponent } from './webcomponents/Authorized'
import { SignInButtonWebComponent } from './webcomponents/SignInButton'
import { SignOutButtonWebComponent } from './webcomponents/SignOutButton'

export async function configureUserspace (opts) {
  const { baseUrl, autoLogin, shadow } = await configure(opts)
  const props = ['theme', 'primary']

  register(AuthorizedWebComponent, 'x-authorized', props, { shadow })
  register(AuthorizedWebComponent, 'x-signed-in', props, { shadow })
  register(NonAuthorizedWebComponent, 'x-non-authorized', props, { shadow })
  register(NonAuthorizedWebComponent, 'x-signed-out', props, { shadow })
  register(ProfileButtonWebComponent, 'x-button', props, { shadow })
  register(BadgeWebComponent, 'x-badge', props, { shadow })
  register(UsersTableWebComponent, 'x-users', props, { shadow })
  register(ProfileSettingsWebComponent, 'x-profile-settings', props, { shadow })
  register(ChangePasswordWebComponent, 'x-change-password', props, { shadow })
  register(SettingsWebComponent, 'x-settings', props, { shadow })
  register(PortalWebComponent, 'x-portal', props, { shadow })
  register(SignInButtonWebComponent, 'x-signin-button', props, { shadow })
  register(SignOutButtonWebComponent, 'x-signout-button', props, { shadow })

  if (autoLogin) {
    await API.fetchSession().catch(() => {
      console.log('[userspace]', 'no session found, redirecting to sign-in', opts)
      window.location.href = baseUrl ? baseUrl + '/sign-in' : '/sign-in'
    })
  }
}

const bool = (val) => val === 'true' || val === 'on' || val === '1'

const script = document.currentScript
if (script) {
  const dataset = script.dataset

  const userspaceOptions = {
    baseUrl: dataset.baseUrl,
    clientId: dataset.clientId,
    autoLogin: bool(dataset.autoLogin),
    autoConfig: bool(dataset.autoConfig)
  }

  configureUserspace(userspaceOptions)
}

globalThis.Userspace = {
  fetchToken
}
