import {
  API,
  Button,
  ErrorMessage,
  Form,
  Submit,
  Header,
  Password,
  useSecuritySettings,
  Config,
  SaveProvider
} from '@userspace-auth/core'

import WebComponent from './WebComponent'
import { useState } from 'react'
import { CheckCircleIcon } from '@heroicons/react/20/solid'

const FormId = 'change-password'

export function ChangePasswordWebComponent (props) {
  return (
    <WebComponent component='change-password' {...props}>
      <ChangePassword />
    </WebComponent>
  )
}

export function ChangePassword () {
  return (
    <SaveProvider>
      <ChangePasswordWithContext />
    </SaveProvider>
  )
}

export function ChangePasswordWithContext () {
  const { settings } = useSecuritySettings()
  const [changed, setChanged] = useState(false)

  const saveSettingsHandler = (data) => {
    return API.changePassword(data).then(_ => {
      setChanged(true)
    })
  }

  if (settings?.set_password) return <SetPassword />

  return (
    <div className='max-w-md'>
      <Header
        title='Change Password'
        description='Change your password'
      />
      {
      changed
        ? <ChangedMessage />
        : <ChangePasswordForm onSubmit={saveSettingsHandler} />
       }
    </div>
  )
}

const ChangedMessage = () => {
  return (
    <div className='mt-8'>
      <div className='rounded-md bg-green-50 p-4'>
        <div className='flex'>
          <div className='shrink-0'>
            <CheckCircleIcon className='h-5 w-5 text-green-400' aria-hidden='true' />
          </div>
          <div className='ml-3'>
            <h3 className='text-sm font-medium text-green-800'>Success</h3>
            <div className='mt-2 text-sm text-green-700'>
              <p>Your password has been changed.</p>
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}

const ChangePasswordForm = ({ onSubmit }) => {
  return (
    <Form
      id={FormId}
      fit
      onSubmit={onSubmit}
      className='mt-8'
    >
      <Password
        label='Old password'
        id='oldPassword'
        name='oldPassword'
        focus
        showForgot
        redirect
        forgotPasswordUrl={Config.urls().ForgotPassword}
      />

      <Password
        label='New password'
        id='newPassword'
        name='newPassword'
        showComplexity
      />

      <ErrorMessage />
      <div className='flex flex-row'>
        <Submit label='Save' />
      </div>
    </Form>
  )
}

const SetPassword = () => {
  const [emailSent, setEmailSent] = useState(false)

  const setPasswordHandler = async (data) => {
    setEmailSent(true)
    API.setPassword()
  }

  const body = !emailSent
    ? (
      <Button
        primary
        className='mt-8'
        label='Set Password'
        onClick={setPasswordHandler}
      />
      )
    : (
      <div className='mt-8'>
        <p className='text-sm text-gray-500'>
          Check your email for a link to set your password.
          If it doesn’t appear within a few minutes, check your spam folder.
        </p>
      </div>
      )

  return (
    <div className='max-w-md'>
      <Header
        title='Set Password'
        description='Your account does not have a password set.'
      />
      <div className='flex'>{body}</div>
    </div>
  )
}
