import WebComponent from './WebComponent'

import {
  useActions,
  useProfile,
  Avatar,
  Dropdown
} from '@userspace-auth/core'

import {
  SettingsModal,
  useSettingsModal
} from './modals/SettingsModal'

export function ProfileButtonWebComponent ({ placement, ...props }) {
  const modal = useSettingsModal()
  return (
    <WebComponent component='profile-button' {...props}>
      <ProfileButton settingModal={modal} placement={placement} />
      <SettingsModal modal={modal} />
    </WebComponent>
  )
}

export function ProfileButton ({ shadowRoot, settingModal, placement }) {
  const { profile } = useProfile()
  const styles = {}
  return (
    <div className='flex' style={styles}>
      <DropdownMenu
        profile={profile}
        shadowRoot={shadowRoot}
        settingModal={settingModal}
        placement={placement}
      />
    </div>
  )
}

const DropdownMenu = ({ profile, shadowRoot, settingModal, placement }) => {
  const { openModal } = settingModal
  const { signOut } = useActions()

  const { Menu, MenuItem } = Dropdown
  const button = (
    <div className='flex items-center h-8 w-8 rounded-full bg-gray-100 text-gray-400 hover:text-gray-600 focus:outline-hidden focus:ring-2 focus:ring-primary focus:ring-offset-2 focus:ring-offset-gray-100'>
      <span className='sr-only'>Open options</span>
      <Avatar profile={profile} />
    </div>
  )
  const panel = (
    <div className='-mt-1 px-4 py-3 bg-gray-50 rounded-t-md'>
      <p className='truncate text-sm font-medium text-gray-900'>{profile?.name}</p>
      <p className='truncate text-sm text-gray-400'>{profile?.email}</p>
    </div>
  )
  return (
    <Menu
      width='w-56 overflow-hidden'
      button={button}
      shadowRoot={shadowRoot}
      placement={placement}
    >
      {panel}
      <MenuItem label='Settings' onClick={openModal} />
      <MenuItem label='Sign out' onClick={signOut} />
    </Menu>
  )
}
