import {
  ErrorMessage,
  Form,
  Input,
  Submit,
  Header,
  useFormData,
  useProfile,
  useUpdateProfile,
  Avatar,
  SaveProvider
} from '@userspace-auth/core'

import WebComponent from './WebComponent'

const FormId = 'profile'

export function ProfileSettingsWebComponent (props) {
  return (
    <WebComponent component='profile-settings' {...props}>
      <ProfileSettings />
    </WebComponent>
  )
}

export function ProfileSettings () {
  return (
    <SaveProvider>
      <ProfileSettingsWithContext />
    </SaveProvider>
  )
}

export function ProfileSettingsWithContext () {
  const { profile } = useProfile()
  const { name, picture, email } = profile || {}
  const { updateProfile } = useUpdateProfile()

  const saveSettingsHandler = async (data) => {
    return updateProfile({ userId: profile.id, ...data })
  }

  return (
    <div>
      <Header
        title='Profile'
        description='Manage your profile and settings'
      />
      <Profile profile={profile} />
      <Form
        id={FormId}
        fit
        onSubmit={saveSettingsHandler}
        className='mt-8'
      >
        <div className='grid grid-cols-2 gap-6'>
          <Input
            focus
            label='Name'
            name='name'
            value={name}
            placeholder='Your name'
            required
          />
          <Input
            label='Email'
            name='email'
            value={email}
            readonly
          />
        </div>
        <Input
          label='Image URL'
          name='picture'
          value={picture}
          placeholder='https://userspace.tech/picture.png'
        />
        <ErrorMessage />
        <div className='flex flex-row'>
          <Submit />
        </div>
      </Form>
    </div>
  )
}

const Profile = ({ profile = {} }) => {
  const formData = useFormData(FormId)
  const { name, email } = { ...profile, ...formData }
  return (
    <div className='flex items-center mt-8'>
      <Avatar
        className='w-20 h-20 rounded-full shadow-lg'
        profile={profile}
      />
      <div className='flex flex-col py-5 pl-6'>
        <strong className='text-slate-900 font-medium dark:text-slate-200'>{name}</strong>
        <span className='text-slate-500 text-sm dark:text-slate-400'>{email}</span>
      </div>
    </div>
  )
}
