import {
  Role,
  useUpdateUserRole,
  useCurrentUser,
  ModalForm
} from '@userspace-auth/core'

import { useModal } from './useModal'

export const useRoleModal = () => {
  const modal = useModal()
  const openRoleModal = ({ userId, role }) => {
    modal.openModal({ userId, role })
  }

  const setRole = (role) => {
    modal.setParam({ role })
  }

  return {
    ...modal,
    openRoleModal,
    setRole
  }
}

export function EditRole ({ modal }) {
  const {
    open,
    closeModal,
    role,
    setRole,
    userId
  } = modal

  const { updateUserRole } = useUpdateUserRole()

  const handleSave = () => {
    updateUserRole({ userId, role })
    closeModal()
  }

  return (
    <ModalForm
      open={open}
      onClose={closeModal}
      title='Edit role'
      description='Change user role'
      onSubmit={handleSave}
    >
      <p className='p-2'>
        <RolesView role={role} setRole={setRole} />
      </p>
    </ModalForm>
  )
}

const roles = [
  {
    id: 'Owner',
    title: 'Owner',
    minRole: Role.Owner,
    notes: 'Owner has access to all resources'
  },
  {
    id: 'Admin',
    title: 'Admin',
    minRole: Role.Admin,
    notes: 'Admin can mange users'
  },
  {
    id: 'Member',
    title: 'Member',
    minRole: Role.Admin,
    notes: 'Member is a happy user'
  }
]

const RolesView = ({ role, setRole }) => {
  const { currentUser } = useCurrentUser()

  const onChange = (e) => {
    setRole(e.target.id)
  }

  // filter roles that are allowed for the current user
  // i.e if the current user is an admin, they can only assign roles that are below admin
  const allowedRoles = roles.filter((r) => currentUser.hasMinRole(r.minRole))

  return (
    <div>
      <fieldset className='mt-4'>
        <legend className='sr-only'>Notification method</legend>
        <div className='space-y-4'>
          {allowedRoles.map((r) => (
            <div key={r.id} className='flex items-start'>
              <input
                id={r.id}
                name='notification-method'
                type='radio'
                onChange={onChange}
                defaultChecked={r.id === role}
                className='h-4 w-4 mt-1 border-gray-300 text-primary focus:ring-primary'
              />
              <div>
                <label htmlFor={r.id} className='ml-3 block text-sm font-medium leading-6 text-gray-900'>
                  {r.title}
                </label>
                <div className='ml-3'>
                  <p className='text-sm text-gray-400'>{r.notes}</p>
                </div>
              </div>
            </div>
          ))}
        </div>
      </fieldset>
    </div>
  )
}
